docker

package
v0.0.0-...-ff5c359 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: Apache-2.0 Imports: 21 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DockerExtractDomain

func DockerExtractDomain(rawURL string) (string, error)

func NewAuthenticatedClient

func NewAuthenticatedClient(ctx context.Context, imageContext dockerTypes.DockerImage, opts ...client.Opt) (*client.Client, error)

func NewDockerDownload

func NewDockerDownload(configs ...cfg.Config) chain.Link

func NewDockerDownloadLayer

func NewDockerDownloadLayer(configs ...cfg.Config) chain.Link

func NewDockerGetLayers

func NewDockerGetLayers(configs ...cfg.Config) chain.Link

func NewDockerLayerToNP

func NewDockerLayerToNP(configs ...cfg.Config) chain.Link

func NewDockerPull

func NewDockerPull(configs ...cfg.Config) chain.Link

func NewDockerSave

func NewDockerSave(configs ...cfg.Config) chain.Link

func NewUnauthenticatedClient

func NewUnauthenticatedClient(ctx context.Context, opts ...client.Opt) (*client.Client, error)

Types

type DockerDownloadLayerLink struct {
	*chain.Base
	// contains filtered or unexported fields
}

DockerDownloadLayerLink downloads a single layer from a Docker registry

func (*DockerDownloadLayerLink) Process

type DockerDownloadLink struct {
	*chain.Base
	// contains filtered or unexported fields
}

DockerDownloadLink downloads Docker images from a registry without requiring the Docker daemon and saves them as tar files.

func (*DockerDownloadLink) Initialize

func (dd *DockerDownloadLink) Initialize() error

func (*DockerDownloadLink) Params

func (dd *DockerDownloadLink) Params() []cfg.Param

func (*DockerDownloadLink) Process

func (dd *DockerDownloadLink) Process(dockerImage *dockerTypes.DockerImage) error
type DockerGetLayersLink struct {
	*chain.Base
	// contains filtered or unexported fields
}

DockerGetLayersLink downloads manifest and emits individual layers of a Docker image

func (*DockerGetLayersLink) Process

func (dgl *DockerGetLayersLink) Process(dockerImage *dockerTypes.DockerImage) error

type DockerLayerToNP

type DockerLayerToNP struct {
	*chain.Base
}

DockerLayerToNP converts downloaded layer data to NoseyParker inputs

func (*DockerLayerToNP) Params

func (dlnp *DockerLayerToNP) Params() []cfg.Param

func (*DockerLayerToNP) Process

func (dlnp *DockerLayerToNP) Process(layer *dockerTypes.DockerLayer) error

type DockerPull

type DockerPull struct {
	*chain.Base
	Client *client.Client
}

func (*DockerPull) Process

func (dp *DockerPull) Process(imageContext dockerTypes.DockerImage) error

type DockerSave

type DockerSave struct {
	*chain.Base
	// contains filtered or unexported fields
}

func (*DockerSave) Initialize

func (dsl *DockerSave) Initialize() error

func (*DockerSave) Params

func (dsl *DockerSave) Params() []cfg.Param

func (*DockerSave) Process

func (dsl *DockerSave) Process(imageContext dockerTypes.DockerImage) error

Jump to