Documentation
¶
Index ¶
- func DockerExtractDomain(rawURL string) (string, error)
- func NewAuthenticatedClient(ctx context.Context, imageContext dockerTypes.DockerImage, opts ...client.Opt) (*client.Client, error)
- func NewDockerDownload(configs ...cfg.Config) chain.Link
- func NewDockerDownloadLayer(configs ...cfg.Config) chain.Link
- func NewDockerGetLayers(configs ...cfg.Config) chain.Link
- func NewDockerLayerToNP(configs ...cfg.Config) chain.Link
- func NewDockerPull(configs ...cfg.Config) chain.Link
- func NewDockerSave(configs ...cfg.Config) chain.Link
- func NewUnauthenticatedClient(ctx context.Context, opts ...client.Opt) (*client.Client, error)
- type DockerDownloadLayerLink
- type DockerDownloadLink
- type DockerGetLayersLink
- type DockerLayerToNP
- type DockerPull
- type DockerSave
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DockerExtractDomain ¶
func NewAuthenticatedClient ¶
func NewAuthenticatedClient(ctx context.Context, imageContext dockerTypes.DockerImage, opts ...client.Opt) (*client.Client, error)
Types ¶
type DockerDownloadLayerLink ¶
DockerDownloadLayerLink downloads a single layer from a Docker registry
func (*DockerDownloadLayerLink) Process ¶
func (ddl *DockerDownloadLayerLink) Process(layer *dockerTypes.DockerLayer) error
type DockerDownloadLink ¶
DockerDownloadLink downloads Docker images from a registry without requiring the Docker daemon and saves them as tar files.
func (*DockerDownloadLink) Initialize ¶
func (dd *DockerDownloadLink) Initialize() error
func (*DockerDownloadLink) Params ¶
func (dd *DockerDownloadLink) Params() []cfg.Param
func (*DockerDownloadLink) Process ¶
func (dd *DockerDownloadLink) Process(dockerImage *dockerTypes.DockerImage) error
type DockerGetLayersLink ¶
DockerGetLayersLink downloads manifest and emits individual layers of a Docker image
func (*DockerGetLayersLink) Process ¶
func (dgl *DockerGetLayersLink) Process(dockerImage *dockerTypes.DockerImage) error
type DockerLayerToNP ¶
DockerLayerToNP converts downloaded layer data to NoseyParker inputs
func (*DockerLayerToNP) Params ¶
func (dlnp *DockerLayerToNP) Params() []cfg.Param
func (*DockerLayerToNP) Process ¶
func (dlnp *DockerLayerToNP) Process(layer *dockerTypes.DockerLayer) error
type DockerPull ¶
func (*DockerPull) Process ¶
func (dp *DockerPull) Process(imageContext dockerTypes.DockerImage) error
type DockerSave ¶
func (*DockerSave) Initialize ¶
func (dsl *DockerSave) Initialize() error
func (*DockerSave) Params ¶
func (dsl *DockerSave) Params() []cfg.Param
func (*DockerSave) Process ¶
func (dsl *DockerSave) Process(imageContext dockerTypes.DockerImage) error
Click to show internal directories.
Click to hide internal directories.